/*
 * BoincSpy database upgrade script.
 *
 * Version: 0.3
 *
 * 0.3 	 June 29th, 2004
 *	 Changes to support multiple projects, stored procedures to retrieve statistics now take a project parameter. BSpy Viewer uses this
 *       to filter based on project. Added stored procedure for Predictor@home
 * 0.4	 July 11th, 2004
 *       Added use BoincSpy.
 */

use BoincSpy
GO
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[getCPUAverages]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure [dbo].[getCPUAverages]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[getElapsedTimeAverages]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure [dbo].[getElapsedTimeAverages]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[getNumWorkUnitsPerDay]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure [dbo].[getNumWorkUnitsPerDay]
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[getNumberofWUsProcessed]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure [dbo].[getNumberofWUsProcessed]
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO


CREATE PROCEDURE dbo.InsertPredictorResult

	(
		@wu_id int,
		@host_name nchar(32),
		@project   nchar(132),
		@wu_name  nchar(60),
		@elapsed_time float,
		@cpu_usage float,
		@Identity int OUTPUT
	)

AS
	INSERT INTO result( wu_id, hostname, project, wu_name, elapsed_time, cpu_usage )
	  VALUES (@wu_id, @host_name, @project, @wu_name,  @elapsed_time, @cpu_usage )
	SET @Identity = SCOPE_IDENTITY()
	RETURN
GO
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO

CREATE       PROCEDURE dbo.getElapsedTimeAverages
	(
		@project   nchar(32),
		@hostname  nchar(32)
	)

AS	
	BEGIN
		select elapsed_avg=sum(elapsed_time) / count(*) 
                  from result
		  where result.project = @project
                    and elapsed_time != 0
	
		select host_elapsed_avg=sum(elapsed_time) / count(*)
                  from result
	         where result.project = @project
		   and elapsed_time != 0
 	           and result.hostname = @hostname
	END
GO
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO

CREATE        PROCEDURE dbo.getNumWorkUnitsPerDay
	(
		@project   nchar(32),
		@hostname  nchar(32)
	)
AS
	
	declare @tmp_var float
	declare @total_avg float
	declare @number_of_avg_day_buckets float

	select @total_avg = 0
	select @number_of_avg_day_buckets =0

	DECLARE Avg_day CURSOR FOR
	select count(*) 
          from result
	where result.project = @project
      group by datepart(year, row_ins_date) + datepart(mm, row_ins_date) + datepart(dd, row_ins_date)

	OPEN Avg_day

	Fetch  next from Avg_day
	   into @tmp_var

	select @total_avg = @total_avg + @tmp_var
	select @number_of_avg_day_buckets = @number_of_avg_day_buckets + 1
	  
	
	while @@fetch_status = 0
	BEGIN
	  Fetch  next from Avg_day
	   into @tmp_var
	   if ( @@fetch_status = 0 )
	   BEGIN
	   select @total_avg = @total_avg + @tmp_var
	   select @number_of_avg_day_buckets = @number_of_avg_day_buckets + 1
	   END
	END

	select  wu_per_day = @total_avg /  @number_of_avg_day_buckets

	CLOSE Avg_day
	DEALLOCATE Avg_day




GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO

CREATE       PROCEDURE dbo.getNumberofWUsProcessed
	(
		@project   nchar(32),
		@hostname  nchar(32)
	)

AS	
	BEGIN
		select total_wus_processed = count(*) 
                  from result
		 where result.project = @project
	
		select host_total_wus_processed = count(*)
                  from result
		 where result.project = @project
 	           and result.hostname = @hostname
		
	END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO

CREATE       PROCEDURE dbo.getCPUAverages
	(
		@project   nchar(32),
		@hostname  nchar(32)
	)

AS	
	BEGIN
		select cpu_avg = sum(cpu_usage) / count(*) 
                  from result
		  where result.project = @project
	
		select host_cpu_avg = sum(cpu_usage) / count(*)
                  from result
		 where result.project = @project
 	           and result.hostname = @hostname
	           
	END
	
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO
/*
 * Set the recorded_jd_time to null as some projects don;t have this..
 */

ALTER TABLE [dbo].[result] alter COLUMN recorded_time_jd float NULL
GO

/*
 * For other projects we cannot use this FK reference.
 */
ALTER TABLE [dbo].[result] DROP 
	CONSTRAINT [FK_result_seti_wu_header] 

GO
